Release notes
=============

This project uses `semantic versioning <http://semver.org/>`_.

1.0.0 (YYYY-MM-DD)
------------------

0.3.0
-----

Fixed
^^^^^

- ``Just.fmap()`` doesn't return Nothing appropriately.

0.2.0
-----

Added
^^^^^

- Identity monad.

0.1.0
-----

Initial release.
